Crate rusty_bubbletea

Crate rusty_bubbletea 

Cleanroom Rust port of upstream Go source file: tea.go Upstream Target Tag / Version: v2.0.8

Package tea provides a framework for building rich terminal user interfaces based on the paradigms of The Elm Architecture. It's well-suited for simple and complex terminal applications, either inline, full-window, or a mix of both. It's been battle-tested in several large projects and is production-ready.

A tutorial is available at https://github.com/charmbracelet/bubbletea/tree/master/tutorials

Example programs can be found at https://github.com/charmbracelet/bubbletea/tree/master/examples

Re-exports

pub use clipboard::*;
pub use color::*;
pub use commands::*;
pub use cursed_renderer::*;
pub use cursor::*;
pub use environ::*;
pub use exec::*;
pub use focus::*;
pub use input::*;
pub use key::*;
pub use keyboard::*;
pub use logging::*;
pub use mod_keys::*;
pub use model::*;
pub use mouse::*;
pub use nil_renderer::*;
pub use options::*;
pub use paste::*;
pub use profile::*;
pub use program::*;
pub use raw::*;
pub use renderer::*;
pub use screen::*;
pub use termcap::*;
pub use tty::*;
pub use view::*;
pub use xterm::*;

Modules

clipboard
Cleanroom Rust port of upstream Go source file: clipboard.go Upstream Target Tag / Version: v2.0.8
color
Cleanroom Rust port of upstream Go source file: color.go Upstream Target Tag / Version: v2.0.8
commands
Cleanroom Rust port of upstream Go source file: commands.go Upstream Target Tag / Version: v2.0.8
cursed_renderer
Cleanroom Rust port of upstream Go source file: cursed_renderer.go Upstream Target Tag / Version: v2.0.8
cursor
Cleanroom Rust port of upstream Go source file: cursor.go Upstream Target Tag / Version: v2.0.8
environ
Cleanroom Rust port of upstream Go source file: environ.go Upstream Target Tag / Version: v2.0.8
exec
Cleanroom Rust port of upstream Go source file: exec.go Upstream Target Tag / Version: v2.0.8
focus
Cleanroom Rust port of upstream Go source file: focus.go Upstream Target Tag / Version: v2.0.8
input
Cleanroom Rust port of upstream Go source file: input.go Upstream Target Tag / Version: v2.0.8
key
Cleanroom Rust port of upstream Go source file: key.go Upstream Target Tag / Version: v2.0.8
keyboard
Cleanroom Rust port of upstream Go source file: keyboard.go Upstream Target Tag / Version: v2.0.8
logging
Cleanroom Rust port of upstream Go source file: logging.go Upstream Target Tag / Version: v2.0.8
mod_keys
Cleanroom Rust port of upstream Go source file: mod.go Upstream Target Tag / Version: v2.0.8
model
Cleanroom Rust port of upstream Go source file: tea.go (Model interface) Upstream Target Tag / Version: v2.0.8
mouse
Cleanroom Rust port of upstream Go source file: mouse.go Upstream Target Tag / Version: v2.0.8
nil_renderer
Cleanroom Rust port of upstream Go source file: nil_renderer.go Upstream Target Tag / Version: v2.0.8
options
Cleanroom Rust port of upstream Go source file: options.go Upstream Target Tag / Version: v2.0.8
paste
Cleanroom Rust port of upstream Go source file: paste.go Upstream Target Tag / Version: v2.0.8
profile
Cleanroom Rust port of upstream Go source file: profile.go Upstream Target Tag / Version: v2.0.8
program
Cleanroom Rust port of upstream Go source file: tea.go (Program runner) Upstream Target Tag / Version: v2.0.8
raw
Cleanroom Rust port of upstream Go source file: raw.go Upstream Target Tag / Version: v2.0.8
renderer
Cleanroom Rust port of upstream Go source file: renderer.go Upstream Target Tag / Version: v2.0.8
screen
Cleanroom Rust port of upstream Go source file: screen.go Upstream Target Tag / Version: v2.0.8
signals_unix
Cleanroom Rust port of upstream Go source file: signals_unix.go Upstream Target Tag / Version: v2.0.8
signals_windows
Cleanroom Rust port of upstream Go source file: signals_windows.go Upstream Target Tag / Version: v2.0.8
termcap
Cleanroom Rust port of upstream Go source file: termcap.go Upstream Target Tag / Version: v2.0.8
termios_bsd
Cleanroom Rust port of upstream Go source file: termios_bsd.go Upstream Target Tag / Version: v2.0.8
termios_other
Cleanroom Rust port of upstream Go source file: termios_other.go Upstream Target Tag / Version: v2.0.8
termios_unix
Cleanroom Rust port of upstream Go source file: termios_unix.go Upstream Target Tag / Version: v2.0.8
termios_windows
Cleanroom Rust port of upstream Go source file: termios_windows.go Upstream Target Tag / Version: v2.0.8
tty
Cleanroom Rust port of upstream Go source file: tty.go Upstream Target Tag / Version: v2.0.8
tty_unix
Cleanroom Rust port of upstream Go source file: tty_unix.go Upstream Target Tag / Version: v2.0.8
tty_windows
Cleanroom Rust port of upstream Go source file: tty_windows.go Upstream Target Tag / Version: v2.0.8
view
Cleanroom Rust port of upstream Go source file: tea.go (View definitions) Upstream Target Tag / Version: v2.0.8
xterm
Cleanroom Rust port of upstream Go source file: xterm.go Upstream Target Tag / Version: v2.0.8