pub struct InterruptMsg;Expand description
InterruptMsg signals the program should interrupt. This usually happens when ctrl+c is pressed on common programs, but since bubbletea puts the terminal in raw mode, we need to handle it in a per-program basis.
You can send this message with interrupt().