Module cursor

Module cursor 

Cleanroom Rust port of upstream Go source file: cursor.go Upstream Target Tag / Version: v2.0.8

# Cursor Position & Shape

Terminal cursor position structures, shape definitions, and position query requests.

Structs

Cursor
Cursor configuration for a View.
CursorPositionMsg
CursorPositionMsg represents the terminal cursor position.
Position
Position represents a position in the terminal.
RequestCursorPosMsg
RequestCursorPosMsg is a message that requests the cursor position.

Enums

CursorShape
CursorShape represents a terminal cursor shape.

Functions

request_cursor_position
RequestCursorPosition is a command that requests the cursor position. The cursor position will be sent as a CursorPositionMsg message.