pub fn request_cursor_position() -> CmdExpand description
RequestCursorPosition is a command that requests the cursor position.
The cursor position will be sent as a CursorPositionMsg message.
pub fn request_cursor_position() -> CmdRequestCursorPosition is a command that requests the cursor position.
The cursor position will be sent as a CursorPositionMsg message.