pub struct KeyboardEnhancementsMsg {
pub flags: i32,
}Expand description
KeyboardEnhancementsMsg is a message that gets sent when the terminal supports keyboard enhancements.
Fields
flags: i32Flags is a bitmask of enabled keyboard enhancement features. A non-zero value indicates that at least we have key disambiguation support.
Use the supports_* methods for the easy way to check individual flags.
Implementations
Sourceimpl KeyboardEnhancementsMsg
impl KeyboardEnhancementsMsg
Sourcepub fn supports_key_disambiguation(&self) -> bool
pub fn supports_key_disambiguation(&self) -> bool
SupportsKeyDisambiguation returns whether the terminal supports key disambiguation (e.g., distinguishing between different modifier keys).
Sourcepub fn supports_event_types(&self) -> bool
pub fn supports_event_types(&self) -> bool
SupportsEventTypes returns whether the terminal supports reporting different types of key events (press, release, and repeat).
Sourcepub fn supports_alternate_keys(&self) -> bool
pub fn supports_alternate_keys(&self) -> bool
SupportsAlternateKeys returns whether the terminal supports reporting alternate key codes.
Sourcepub fn supports_all_keys_as_escape_codes(&self) -> bool
pub fn supports_all_keys_as_escape_codes(&self) -> bool
SupportsAllKeysAsEscapeCodes returns whether the terminal supports reporting all keys as escape codes.
Sourcepub fn supports_associated_text(&self) -> bool
pub fn supports_associated_text(&self) -> bool
SupportsAssociatedText returns whether the terminal supports reporting associated text with key events.