Cleanroom Rust port of upstream Go source file: tea.go (Model interface)
Upstream Target Tag / Version: v2.0.8
A tutorial is available at https://github.com/charmbracelet/bubbletea/tree/master/tutorials
Example programs can be found at https://github.com/charmbracelet/bubbletea/tree/master/examples
Traits
- Model
- Model defines the application state machine according to The Elm Architecture in Bubble Tea v2.0.8.
- Msg
- Msg represents an event message delivered to the Model’s Update function.
Type Aliases
- Cmd
- Cmd is an asynchronous command closure returning an optional Msg.