WithContext lets you specify a context in which to run the Program. This is
useful if you want to cancel the execution from outside. When a Program gets
cancelled it will exit with an error ErrProgramKilled.
WithEnvironment sets the environment variables that the program will use.
This is useful when the program is running in a remote session (e.g. SSH) and
you want to pass the environment variables from the remote session to the
program.
WithoutCatchPanics disables the panic catching that Bubble Tea does by
default. If panic catching is disabled the terminal will be in a fairly
unusable state after a panic because Bubble Tea will not perform its usual
cleanup on exit.
WithoutRenderer disables the renderer. When this is set output and log
statements will be plainly sent to stdout (or another output if one is set)
without any rendering and redrawing logic.
WithFilter supplies an event filter that will be invoked before Bubble Tea
processes a tea.Msg. The event filter can return any tea.Msg which will then
get handled by Bubble Tea instead of the original event. If the event filter
returns None, the event will be ignored and Bubble Tea will not process it.
WithFPS sets a custom maximum FPS at which the renderer should run. If
less than 1, the default value of 60 will be used. If over 120, the FPS
will be capped at 120.
WithWindowSize sets the initial size of the terminal window. This is useful
when you need to set the initial size of the terminal window, for example
during testing or when you want to run your program in a non-interactive
environment.