Module paste

Module paste 

Cleanroom Rust port of upstream Go source file: paste.go Upstream Target Tag / Version: v2.0.8

# Bracketed Paste Messages

Paste messages (PasteMsg, PasteStartMsg, PasteEndMsg) emitted when receiving bracketed paste text.

Structs

PasteEndMsg
PasteEndMsg is a message that is emitted when the terminal ends the bracketed-paste text.
PasteMsg
PasteMsg is a message that is emitted when a terminal receives pasted text using bracketed-paste.
PasteStartMsg
PasteStartMsg is a message that is emitted when the terminal starts the bracketed-paste text.