Module program

Module program 

Cleanroom Rust port of upstream Go source file: tea.go (Program runner) Upstream Target Tag / Version: v2.0.8

Package tea provides a framework for building rich terminal user interfaces based on the paradigms of The Elm Architecture. It's well-suited for simple and complex terminal applications, either inline, full-window, or a mix of both. It's been battle-tested in several large projects and is production-ready.

A tutorial is available at https://github.com/charmbracelet/bubbletea/tree/master/tutorials

Example programs can be found at https://github.com/charmbracelet/bubbletea/tree/master/examples

Structs

Program
Program is the runner for a Bubble Tea v2.0.8 application.

Enums

ProgramError
ProgramError is the error type returned by Program::run.

Constants

ERR_INTERRUPTED
ErrInterrupted is returned by [Program.Run] when the program get a SIGINT signal, or when it receives a InterruptMsg.
ERR_PROGRAM_KILLED
ErrProgramKilled is returned by [Program.Run] when the program gets killed.
ERR_PROGRAM_PANIC
ErrProgramPanic is returned by [Program.Run] when the program recovers from a panic.