Program

Struct Program 

pub struct Program<M: Model> { /* private fields */ }
Program is the runner for a Bubble Tea v2.0.8 application.

Implementations

Source

impl<M: Model> Program<M>

pub fn new(model: M) -> Self

Creates a new Program for the given model with default options.

pub fn with_options(self, options: ProgramOptions<M>) -> Self

Sets custom program options.

pub fn send(&self, msg: Box<dyn Msg>)

Send sends a message to the main update function, effectively allowing messages to be injected from outside the program for interoperability purposes.

pub fn quit(&self)

Quit is a convenience function for quitting Bubble Tea programs. Use it when you need to shut down a Bubble Tea program from the outside.

pub fn kill(&mut self)

Kill stops the program immediately and restores the former terminal state. The final render that you would normally see when quitting will be skipped. [Program.Run] returns a [ErrProgramKilled] error.

pub fn wait(&self)

Wait waits/blocks until the underlying Program finished shutting down.

pub fn println(&self, args: &str)

Println prints above the Program. This output is unmanaged by the program and will persist across renders by the Program.

pub fn printf(&self, body: &str)

Printf prints above the Program. It takes a format template followed by values similar to fmt.Printf.

pub fn run(self) -> Result<M, Box<dyn Error>>

Runs the Bubble Tea v2.0.8 event loop until quit.