clear_screen

Function clear_screen 

pub fn clear_screen() -> Cmd
ClearScreen is a special command that tells the program to clear the screen before the next update. This can be used to move the cursor to the top left of the screen and clear visual clutter when the alt screen is not in use.

Note that it should never be necessary to call clear_screen for regular redraws.