pub struct ModeReportMsg {
pub mode: u32,
pub value: u32,
}Expand description
ModeReportMsg is a message that represents a mode report event (DECRPM).
This is sent by the terminal in response to a request for a terminal mode report (DECRQM). It indicates the current setting of a specific terminal mode like cursor visibility, mouse tracking, etc.
Fields
mode: u32Mode is the mode number.
value: u32Value is the mode setting value.