WindowSizeMsg

Struct WindowSizeMsg 

pub struct WindowSizeMsg {
    pub width: usize,
    pub height: usize,
}
WindowSizeMsg is used to report the terminal size. It’s sent to update once initially and then on every terminal resize. Note that Windows does not have support for reporting when resizes occur as it does not support the SIGWINCH signal.

Fields

width: usize

Width of terminal in columns.

height: usize

Height of terminal in rows.