Cleanroom Rust port of upstream Go source file: termcap.go
Upstream Target Tag / Version: v2.0.8
Terminal capability query requests (request_capability) and responses (CapabilityMsg).
Structs
- Capability
Msg - CapabilityMsg represents a Termcap/Terminfo response event. Termcap
responses are generated by the terminal in response to
request_capability(XTGETTCAP) requests. - Request
Capability Msg - RequestCapabilityMsg is an internal message that requests the terminal to send its Termcap/Terminfo response.
Functions
- request_
capability - RequestCapability is a command that requests the terminal to send its Termcap/Terminfo response for the given capability.