Module view

Module view 

Cleanroom Rust port of upstream Go source file: tea.go (View definitions) Upstream Target Tag / Version: v2.0.8

Package tea provides a framework for building rich terminal user interfaces based on the paradigms of The Elm Architecture. It's well-suited for simple and complex terminal applications, either inline, full-window, or a mix of both. It's been battle-tested in several large projects and is production-ready.

A tutorial is available at https://github.com/charmbracelet/bubbletea/tree/master/tutorials

Example programs can be found at https://github.com/charmbracelet/bubbletea/tree/master/examples

Structs

ProgressBar
ProgressBar represents the terminal progress bar.
View
View represents a declarative terminal view in Bubble Tea v2.0.8.

Enums

MouseMode
MouseMode enum for declarative views.
ProgressBarState
ProgressBarState represents the state of the progress bar.

Functions

new_progress_bar
NewProgressBar returns a new progress bar with the given state and value. The value is ignored if the state is ProgressBarState::ProgressBarNone or ProgressBarState::ProgressBarIndeterminate.

Type Aliases

OnMouseFn
OnMouseFn closure type for View mouse handlers.