pub struct ProgressBar {
pub state: ProgressBarState,
pub value: usize,
}Expand description
ProgressBar represents the terminal progress bar.
Support depends on the terminal.
See https://learn.microsoft.com/en-us/windows/terminal/tutorials/progress-bar-sequences
Fields
state: ProgressBarStateState is the current state of the progress bar. It can be one of ProgressBarState::ProgressBarNone, ProgressBarState::ProgressBarDefault, ProgressBarState::ProgressBarError, ProgressBarState::ProgressBarIndeterminate, and ProgressBarState::ProgressBarWarning.
value: usizeValue is the current value of the progress bar. It should be between 0 and 100.