Cleanroom Rust port of upstream Go source file: xterm.go
Upstream Target Tag / Version: v2.0.8
Terminal version queries (request_terminal_version) and responses (TerminalVersionMsg).
Structs
- Request
Terminal Version Msg - RequestTerminalVersionMsg is sent internally to request terminal version.
- Terminal
Version Msg - TerminalVersionMsg represents the terminal version (XTVERSION).
Functions
- request_
terminal_ version - RequestTerminalVersion is a command that queries the terminal for its version using XTVERSION. Note that some terminals may not support this command.