Cleanroom Rust port of upstream Go source file: cursor.go
Upstream Target Tag / Version: v2.0.8
Terminal cursor position structures, shape definitions, and position query requests.
Structs
- Cursor
- Cursor configuration for a View.
- Cursor
Position Msg - CursorPositionMsg represents the terminal cursor position.
- Position
- Position represents a position in the terminal.
- Request
Cursor PosMsg - RequestCursorPosMsg is a message that requests the cursor position.
Enums
- Cursor
Shape - CursorShape represents a terminal cursor shape.
Functions
- request_
cursor_ position - RequestCursorPosition is a command that requests the cursor position.
The cursor position will be sent as a
CursorPositionMsgmessage.