Module model

Module model 

Cleanroom Rust port of upstream Go source file: tea.go (Model interface) Upstream Target Tag / Version: v2.0.8

Package tea provides a framework for building rich terminal user interfaces based on the paradigms of The Elm Architecture. It's well-suited for simple and complex terminal applications, either inline, full-window, or a mix of both. It's been battle-tested in several large projects and is production-ready.

A tutorial is available at https://github.com/charmbracelet/bubbletea/tree/master/tutorials

Example programs can be found at https://github.com/charmbracelet/bubbletea/tree/master/examples

Traits

Model
Model defines the application state machine according to The Elm Architecture in Bubble Tea v2.0.8.
Msg
Msg represents an event message delivered to the Model’s Update function.

Type Aliases

Cmd
Cmd is an asynchronous command closure returning an optional Msg.