Cleanroom Rust port of upstream Go source file: paste.go
Upstream Target Tag / Version: v2.0.8
Paste messages (PasteMsg, PasteStartMsg, PasteEndMsg) emitted when receiving bracketed paste text.
Structs
- Paste
EndMsg - PasteEndMsg is a message that is emitted when the terminal ends the bracketed-paste text.
- Paste
Msg - PasteMsg is a message that is emitted when a terminal receives pasted text using bracketed-paste.
- Paste
Start Msg - PasteStartMsg is a message that is emitted when the terminal starts the bracketed-paste text.