Cleanroom Rust port of upstream Go source file: screen.go
Upstream Target Tag / Version: v2.0.8
WindowSizeMsg, clear_screen, ClearScreenMsg, ModeReportMsg.
Structs
- Clear
Screen Msg - ClearScreenMsg is an internal message that signals to clear the screen.
You can send a ClearScreenMsg with
clear_screen. - Mode
Report Msg - ModeReportMsg is a message that represents a mode report event (DECRPM).
- Window
Size Msg - WindowSizeMsg is used to report the terminal size. It’s sent to
updateonce initially and then on every terminal resize. Note that Windows does not have support for reporting when resizes occur as it does not support the SIGWINCH signal.
Functions
- clear_
screen - ClearScreen is a special command that tells the program to clear the screen before the next update. This can be used to move the cursor to the top left of the screen and clear visual clutter when the alt screen is not in use.