pub fn request_capability(s: &str) -> CmdExpand description
RequestCapability is a command that requests the terminal to send its Termcap/Terminfo response for the given capability.
Bubble Tea recognizes the following capabilities and will use them to upgrade the program’s color profile:
"RGB"Xterm direct color"Tc"True color support
Note: that some terminal’s like Apple’s Terminal.app do not support this and will send the wrong response to the terminal breaking the program’s output.
When the Bubble Tea advertises a non-TrueColor profile, you can use this command to query the terminal for its color capabilities.