Cleanroom Rust port of upstream Go source file: tea.go (View definitions)
Upstream Target Tag / Version: v2.0.8
A tutorial is available at https://github.com/charmbracelet/bubbletea/tree/master/tutorials
Example programs can be found at https://github.com/charmbracelet/bubbletea/tree/master/examples
Structs
- Progress
Bar - ProgressBar represents the terminal progress bar.
- View
- View represents a declarative terminal view in Bubble Tea v2.0.8.
Enums
- Mouse
Mode - MouseMode enum for declarative views.
- Progress
BarState - ProgressBarState represents the state of the progress bar.
Functions
- new_
progress_ bar - NewProgressBar returns a new progress bar with the given state and value. The value is ignored if the state is ProgressBarState::ProgressBarNone or ProgressBarState::ProgressBarIndeterminate.
Type Aliases
- OnMouse
Fn - OnMouseFn closure type for View mouse handlers.