Module xterm

Module xterm 

Cleanroom Rust port of upstream Go source file: xterm.go Upstream Target Tag / Version: v2.0.8

# XTerm Commands & Messages

Terminal version queries (request_terminal_version) and responses (TerminalVersionMsg).

Structs

RequestTerminalVersionMsg
RequestTerminalVersionMsg is sent internally to request terminal version.
TerminalVersionMsg
TerminalVersionMsg represents the terminal version (XTVERSION).

Functions

request_terminal_version
RequestTerminalVersion is a command that queries the terminal for its version using XTVERSION. Note that some terminals may not support this command.